==> HostCMS.Free_6.7.tar.gz: modules/xsl/i18n/en.php <==
<?php
/**
 * XSL.
 *
 * @package HostCMS
 * @subpackage Xsl
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'XSL templates',
	'menu' => 'XSL',
	'tab2' => 'Description',
	'tab_dtd' => '%s.dtd',
	'edit_success' => 'XSL template information modified successfully!',
	'markDeleted_success' => 'XSL template deleted successfully!',
	'apply_success' => 'Information modified successfully!',
	'copy_success' => 'Template copied successfully!',
	'add_title' => 'Add XSL template information',
	'edit_title' => 'Edit XSL template information',
	'id' => 'Id',
	'xsl_dir_id' => '<acronym title="Select XSL template section">XSL template section</acronym>',
	'name' => '<acronym title="Name of XSL template">Name of XSL template</acronym>',
	'sorting' => '<acronym title="Order number of XSL template in the list of section templates">Order number of XSL template</acronym>',
	'value' => '<acronym title="Code of XSL template">Code of XSL template</acronym>',
	'dtd' => '<acronym title="DTD for language">DTD for "%s" language</acronym>',
	'format' => '<acronym title="Format of XSL document">Format of XSL template</acronym>',
	'description' => '<acronym title="Additional information on XSL template in free format">Description</acronym>',
	'xsl_already_exists' => 'XSL template with this name already exists! Enter a unique name of XSL template',
	'main_menu' => 'XSL template',
	'panel_edit_xsl' => 'Edit XSL template "%s"',
	'panel_edit_xml' => 'XML for XSL template "%s"',
	'panel_xsl_time' => '%.3f sec.',
	'panel_xsl_size' => '%s bytes',
	'XSL_dir_title' => 'XSL sections',
	'XSL_root_dir' => 'XSL templates',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
);

==> HostCMS.Free_7.0.tar.gz: modules/xsl/i18n/en.php <==
<?php
/**
 * XSL.
 *
 * @package HostCMS
 * @subpackage Xsl
 * @version 7.x
 * @author Hostmake LLC
 * @copyright © 2005-2022 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'XSL templates',
	'menu' => 'XSL',
	'tab2' => 'Description',
	'tab_dtd' => '%s.dtd',
	'edit_success' => 'XSL template information modified successfully!',
	'markDeleted_success' => 'XSL template deleted successfully!',
	'apply_success' => 'Information modified successfully!',
	'copy_success' => 'Template copied successfully!',
	'add_title' => 'Add XSL template information',
	'edit_title' => 'Edit XSL template information',
	'id' => 'ID',
	'xsl_dir_id' => 'XSL template section',
	'name' => 'Name of XSL template',
	'sorting' => 'Sort',
	'value' => 'Code of XSL template',
	'dtd' => 'DTD for "%s" language',
	'format' => 'Format of XSL template',
	'description' => 'Description',
	'xsl_already_exists' => 'XSL template with this name already exists! Enter a unique name of XSL template',
	'main_menu' => 'XSL template',
	'panel_edit_xsl' => 'Edit XSL template "%s"',
	'panel_edit_xml' => 'XML for XSL template "%s"',
	'panel_xsl_time' => '%.3f sec.',
	'panel_xsl_size' => '%s bytes',
	'XSL_dir_title' => 'XSL sections',
	'XSL_root_dir' => 'XSL templates',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'option_formatOutput' => 'Format output',
	'import' => 'Import',
	'import_file' => 'Choose file to upload',
	'import_button' => 'Upload',
	'importXsls_success' => 'Import completed successfully!',
);
